@@ -58,7 +58,7 @@ class Command(BaseCommand):
             )
             return
 
-        theme: Theme = Theme.get_active_theme()
+        theme: Theme = Theme.objects.get_active()
         theme_settings.update(env_themes[env.lower()])
         # update theme name if set to APP_NAME key
         if theme_settings['title'] == 'APP_NAME':
